@@ -200,79 +200,81 @@ class Response(object):
 		
 		#
 	
-	# init a response blank object.
+	# serialize a variable.
 	def serialize(self, 
-		# the response (#1) (dict) (str repr of dict) (ResponseObject) (generator) .
-		response={}, 
-		# init to response object.
-		init=True,
+		# the variable to serialize.
+		variable={}, 
+		# serialize to json format.
+		json=False,
 	):
-
-		# check async generator.
-		if response.__class__.__name__ in ["generator"]:
-			raise ValueError("Not supported yet.")
-			return self.serialize(response=response.value, init=init)
-			#print("Converting generator.")
-			#print(f"Generator value ({response.value.__class__.__name__}) [{response.value}].")
-			#try:
-			#	value = next(response)
-			#except StopIteration as e:
-			#	return self.serialize(response=str(e), init=True)
-			#	#print(f"Generator output: [{e}].")
-			#	#response = self.serialize(response=str(e), init=True)
-			#	#print(f"Serialized generator output instance: [{response.__class__.__name__}].")
-			#	#return response
-			#except Eception as e:
-			#	return _response_.error(f"An error occured during the execution of generator [{response}], error: {e}")
-
-		# check ResponseObject.
-		elif response.__class__.__name__ in ["ResponseObject"]:
-			return response
-		
-		# check Output.
-		elif response.__class__.__name__ in ["OutputObject"]:
-			try:
-				return _response_.response()
-			except AttributeError:
-				return response
-
-		# dict / str.
-		elif response.__class__.__name__ in ["str", "String", "dict", "Dictionary"]:
-			if response.__class__.__name__ in ["str", "String"]:
+		if variable.__class__.__name__ in ["str", "String", "NoneType", "bool", "Boolean"]:
+			if str(variable) in ["true", "True", "TRUE", True]:
+				if json:
+					return "true"
+				else:
+					return True
+			elif str(variable) in ["false", "False", "FALSE", False]:
+				if json:
+					return "false"
+				else:
+					return False
+			elif str(variable) in ["null", "None", "Nan", None]:
+				if json:
+					return "null"
+				else:
+					return None
+			else:
+				integer = None
 				try:
-					try:
-						response = ast.literal_eval(response)
-					except:
-						response = json.loads(response)
-				except Exception as e: 
-					raise Exceptions.JsonDecodeError(f"Unable to parse a dictionary from [{response}], {e}.")
-			for key in list(response.keys()):
-				value = response[key]
-				no_dict = False
-				if isinstance(value, dict):
-					value = self.serialize(value)
-				elif value in [None, "None", "none", "null"]: value = None
-				elif value in [True, "True", "true", "TRUE"]: value = True
-				elif value in [False, "False", "false", "FALSE"]: value = False
-				elif isinstance(value, str):
-					if "." in value:
-						try: value = float(value)
-						except: a=1
+					if "." in str(variable):
+						integer = float(variable)
 					else:
-						try: value = int(value)
-						except: a=1
-				response[key] = value
-
-		# invalid.
+						integer = int(variable)
+				except:
+					integer = None
+				if integer != None:
+					return integer
+				else:
+					try:
+						variable = pypi_json.loads(variable)
+					except:
+						try:
+							variable = ast.literal_eval(variable)
+						except:
+							try:
+								variable = pypi_json.loads(String(variable).slice_dict())
+							except: 
+								return variable
+		elif isinstance(variable, ResponseObject):
+			variable = variable.dict()
+		elif variable.__class__.__name__ in ["OutputObject"]:
+			variable = variable.response().dict()
+		elif isinstance(variable, (dict,Dictionary, list, Array)):
+			variable = variable
+		elif json and not isinstance(variable, (Dictionary)) and isinstance(variable, object):
+			if isinstance(variable, (Integer)):
+				return variable.value	
+			elif isinstance(variable, (Boolean)):
+				return variable.bool
+			elif variable in [None, "None"]:
+				return None
+			else:
+				return str(variable)
 		else:
-			raise Exceptions.InvalidUsage(f"The parameter [response] must be [str, String, dict, Dictionary, generator] not [{response.__class__.__name__}].")
-
-		# return dict.
-		if init:
-			return ResponseObject(response)
+			return variable
+		if isinstance(variable, (dict, Dictionary)):
+			_variable_ = {}
+			for key, value in variable.items():
+				_variable_[key] = self.serialize(variable=value, json=json)
+			return _variable_
+		elif isinstance(variable, (list, Array)):
+			_variable_ = []
+			for value in variable:
+				_variable_.append(self.serialize(variable=value, json=json))
+			return _variable_
 		else:
-			return response
-
+			return variable
+		
 		#
 	def response(self, 
 		# the blank response (dict, str, generator) (#1).
@@ -283,7 +285,7 @@ class Response(object):
 		},
 	):
 		# serialize shortcut.
-		return self.serialize(response, init=True)
+		return self.ResponseObject(response)
 		#
 
 	# system functions.
@@ -316,23 +318,14 @@ class Response(object):
 			return response
 			
 		#
-	def __serialize__(self, variable):
-		if isinstance(variable, (dict,Dictionary)):
-			new = {}
-			for key,value in variable.items():
-				new[key] = self.__serialize__(value)
-			variable = new
-		elif variable in [None, "None", "none", "null"]: variable = None
-		elif variable in [True, "True", "true", "TRUE"]: variable = True
-		elif variable in [False, "False", "false", "FALSE"]: variable = False
-		elif isinstance(variable, (String,str)):
-			if "." in variable:
-				try: variable = float(variable)
-				except: a=1
-			else:
-				try: variable = int(variable)
-				except: a=1
-		return variable
+
+	# quote & unqoute dict.
+	def quote(self, dictionary):
+		return urllib.parse.quote(json.dumps(dictionary))
+		#
+	def unquote(self, encoded):
+		return json.loads(urllib.parse.unquote(encoded))
+		#
 
 	#
 	
@@ -347,6 +340,7 @@ class Parameters(object):
 			"description":[], }
 
 		#
+	
 	# get request parameters.
 	def get(self, 
 		# the django request (1).
@@ -364,6 +358,8 @@ class Parameters(object):
 		
 		# single parameter.
 		if isinstance(parameters, (str,String)):
+
+			# get params & format.
 			parameters = str(parameters)
 			format = None
 			if ":" in parameters:
@@ -371,6 +367,8 @@ class Parameters(object):
 				while True:
 					if " " in format: format = format.replace(" ","")
 					else: break
+
+			# get variable.
 			if request.method in ["post", "POST"]:
 				variable = request.POST.get(parameters)
 			else:
@@ -380,16 +378,51 @@ class Parameters(object):
 					return variable, _response_.error(f"{traceback}: Define parameter: [{parameters}].")
 				else:
 					return variable, _response_.error(f"Define parameter: [{parameters}].")
-			elif format != None:
-				if format.lower() in ["str", "string"]: variable = str(variable)
-				elif format.lower() in ["int", "integer"]: variable = int(variable)
-				elif format.lower() in ["bool", "boolean"]: 
-					if variable in ["true", "True", "TRUE", True]: variable = True
-					else: variable = False
-				elif format.lower() in ["float", "double"]: variable = float(variable)
-				elif format.lower() in ["array", "list"]: variable = variable.split(",")
-				else:
-					raise ValueError(f"Unrecognized <dev0s.response.parameters.get> format: {format}.")
+
+			# handle format.
+			if format != None:
+				format_options = format.split(",")
+				found = False
+				for format in format_options:
+					if format.lower() in ["str", "string"]: 
+						try:
+							variable = str(variable)
+							found = True
+						except: a=1
+					elif format.lower() in ["int", "integer"]: 
+						try:
+							variable = int(variable)
+							found = True
+						except: a=1
+					elif format.lower() in ["bool", "boolean"]: 
+						try:
+							if variable in ["true", "True", "TRUE", True]: variable = True
+							else: variable = False
+							found = True
+						except: a=1
+					elif format.lower() in ["float", "double"]: 
+						try:
+							variable = float(variable)
+							found = True
+						except: a=1
+					elif format.lower() in ["array", "list", "dict", "dictionary"]: 
+						try:
+							variable = ast.literal_eval(variable)
+							found = True
+						except:
+							try:
+								variable = json.loads(variable)
+								found = True
+							except:
+								a=1
+					else:
+						raise Exceptions.InvalidUsage(f"Selected format [{format}] is not a valid format option.")
+					if found:
+						break
+				if not found:
+					return variable, _response_.error(f"Unable to parse excepted format [{Array(format_options).string(joiner=', ')}] from parameter [{parameters}:{variable}].")
+
+			# normalize.
 			if variable == "None": variable = None
 
 			# handler.
@@ -504,78 +537,11 @@ class ResponseObject(object):
 	):
 
 		# serialize attributes to dict.
-		def serialize(attributes, all_formats_allowed=False):
-			if isinstance(attributes, ResponseObject):
-				attributes = attributes.dict()
-			elif attributes.__class__.__name__ in ["OutputObject"]:
-				attributes = attributes.response().dict()
-			elif isinstance(attributes, (dict,Dictionary)):
-				attributes = attributes
-			elif isinstance(attributes, (str,String)):
-				if attributes in ["true", "True", "TRUE", True]:
-					attributes = True
-				elif attributes in ["false", "False", "FALSE", False]:
-					attributes = False
-				elif attributes in ["null", "None", "Nan", None]:
-					attributes = None
-				else:
-					integer = None
-					try:
-						if "." in attributes:
-							integer = float(attributes)
-						else:
-							integer = int(attributes)
-					except:
-						integer = None
-					if integer != None:
-						attributes = integer
-					else:
-						try:
-							attributes = pypi_json.loads(attributes)
-						except:
-							try:
-								attributes = ast.literal_eval(attributes)
-							except:
-								try:
-									attributes = pypi_json.loads(String(attributes).slice_dict())
-								except Exception as e:
-									if all_formats_allowed:
-										attributes = attributes
-									else:
-										raise Exceptions.InvalidUsage(f"<ResponseObject.attributes>: unable to parse a dict from attributes [str] [{attributes}].")
-			else:
-				if all_formats_allowed:
-					attributes = attributes
-				else:
-					raise Exceptions.InvalidUsage(f"<ResponseObject.attributes>: parameter [attributes] must be a [dict, dict in str format], not [{attributes.__class__.__name__}].")
-			if isinstance(attributes, (dict,Dictionary)):
-				_attributes_ = {}
-				for key, value in attributes.items():
-					_attributes_[key] = serialize(value, all_formats_allowed=True)
-				return _attributes_
-			else:
-				if attributes in ["true", "True", "TRUE", True]:
-					return True
-				elif attributes in ["false", "False", "FALSE", False]:
-					return False
-				elif attributes in ["null", "None", "Nan", None]:
-					return None
-				else:
-					integer = None
-					try:
-						if "." in attributes:
-							integer = float(attributes)
-						else:
-							integer = int(attributes)
-					except:
-						integer = None
-					if integer != None:
-						return integer
-					else:
-						return attributes
-		self.assign(serialize(attributes))
+		serialized = _response_.serialize(attributes)
+		if not isinstance(serialized, (dict, Dictionary)):
+			raise Exceptions.InvalidUsage(f"<ResponseObject.attributes>: parameter [attributes] must be a [dict, dict in str format], not [{attributes.__class__.__name__}].")
+		self.assign(serialized)
 		
-
 		# catch error so you can also init custom ResponseObjects.
 		try:
 
@@ -643,11 +609,11 @@ class ResponseObject(object):
 	# assign dict.
 	def assign(self, dictionary):
 		if isinstance(dictionary, (dict, Dictionary)):
-			for key,value in response.__serialize__(dictionary).items():
+			for key,value in _response_.serialize(dictionary).items():
 				self[key] = value
 		elif isinstance(dictionary, (tuple, list, Array)):
 			for key,value in dictionary:
-				self[key] = response.__serialize__(value)
+				self[key] = _response_.serialize(value)
 		else:
 			raise Exceptions.InvalidUsage("The dictionary parameter must be a dict or tuple.")
 		return self
@@ -762,43 +728,23 @@ class ResponseObject(object):
 	# dump json string.
 	def json(self, sorted=False, reversed=False, indent=4, dictionary=None, ):
 		if dictionary == None: dictionary = self.dict()
-		return json.dumps(self.serialize(json=False, sorted=sorted, reversed=reversed, dictionary=dictionary), indent=indent).replace(': "False"', ': false').replace(': "True"', ': true').replace(': "None"', ': null')
+		return json.dumps(self.serialize(json=True, sorted=sorted, reversed=reversed, dictionary=dictionary), indent=indent).replace(': "false"', ': false').replace(': "true"', ': true').replace(': "null"', ': null')
 	# serialize dict.
 	def serialize(self, sorted=False, reversed=False, json=False, dictionary=None):
 		if dictionary == None: dictionary = self.dict()
 		if isinstance(dictionary, Dictionary):
 			dictionary = dictionary.dictionary
 		if sorted:
-			items = self.items(reversed=reversed, dictionary=self.sort(alphabetical=True, dictionary=dictionary))
+			d = {}
+			for key, value in self.items(reversed=reversed, dictionary=self.sort(alphabetical=True, dictionary=dictionary)):
+				d[key] = value
+			dictionary = d
 		else:
-			items = self.items(reversed=reversed, dictionary=dictionary)
-		dictionary = {}
-		for key, value in items:
-			value = Formats.denitialize(value)
-			if isinstance(value, (dict, Dictionary)):
-				value = self.serialize(json=json, sorted=sorted, reversed=reversed, dictionary=value)
-			elif isinstance(value, (list, Array)):
-				value = Array(value).serialize(json=json, sorted=sorted, reversed=reversed)
-			elif isinstance(value, object):
-				value = str(value)
-			elif isinstance(value, str) or isinstance(value, bool) or value == None:
-				if value in [True, "True", "True".lower()]: 
-					if json:
-						value = "true"
-					else: 
-						value = True
-				elif value in [False, "False", "False".lower()]: 
-					if json:
-						value = "false"
-					else: 
-						value = False
-				elif value in [None, "None", "None".lower()]: 
-					if json:
-						value = "null"
-					else: 
-						value = None
-			dictionary[key] = value
-		return dictionary
+			d = {}
+			for key, value in self.items(reversed=reversed, dictionary=dictionary):
+				d[key] = value
+			dictionary = d
+		return _response_.serialize(variable=dictionary, json=json)
 	# support default iteration.
 	def __iter__(self):
 		return iter(self.keys())
